@@ -4,8 +4,19 @@ import ctypes
 import logging
 import textwrap
 
-from ctypes import (addressof, byref, cast, c_double, c_float, c_int8, c_int16,
-                    c_int32, c_int64, c_void_p, POINTER)
+from ctypes import (
+    addressof,
+    byref,
+    cast,
+    c_double,
+    c_float,
+    c_int8,
+    c_int16,
+    c_int32,
+    c_int64,
+    c_void_p,
+    POINTER,
+)
 
 from ..tecutil import _tecutil, _tecutil_connector
 from ..constant import *
@@ -100,6 +111,7 @@ class Array(c_void_p):
         `ContourLevels.reset()` or similar. This will ensure that the total
         range of the new values is presented in the plot.
     """
+
     def __init__(self, zone, variable):
         self.zone = zone
         self.variable = variable
@@ -114,12 +126,12 @@ class Array(c_void_p):
             return False
 
     def _delete_cache(self):
-        attrs = '''
+        attrs = """
             _rnr _wnr _rrp _wrp
             _location
             _len
             _data_type
-        '''.split()
+        """.split()
         for attr in attrs:
             try:
                 delattr(self, attr)
@@ -127,12 +139,18 @@ class Array(c_void_p):
                 pass
 
     def _native_reference(self, writable=False):
-        args = (self.zone.dataset.uid, self.zone.index + 1, self.variable.index + 1)
+        args = (
+            self.zone.dataset.uid,
+            self.zone.index + 1,
+            self.variable.index + 1,
+        )
         if writable:
             if self._cache:
                 if not hasattr(self, '_wnr'):
                     with tecutil.lock():
-                        self._wnr = _tecutil.DataValueGetWritableNativeRefByUniqueID(*args)
+                        self._wnr = _tecutil.DataValueGetWritableNativeRefByUniqueID(
+                            *args
+                        )
                 return self._wnr
             else:
                 with tecutil.lock():
@@ -141,7 +159,9 @@ class Array(c_void_p):
             if self._cache:
                 if not hasattr(self, '_rnr'):
                     with tecutil.lock():
-                        self._rnr = _tecutil.DataValueGetReadableNativeRefByUniqueID(*args)
+                        self._rnr = _tecutil.DataValueGetReadableNativeRefByUniqueID(
+                            *args
+                        )
                 return self._rnr
             else:
                 with tecutil.lock():
@@ -154,8 +174,9 @@ class Array(c_void_p):
             raise TecplotLogicError(msg)
         elif writable:
             ref = self._native_reference(writable=True)
-            _tecutil.handle.tecUtilDataValueGetWritableRawPtrByRef.restype = \
-                POINTER(self.c_type)
+            _tecutil.handle.tecUtilDataValueGetWritableRawPtrByRef.restype = POINTER(
+                self.c_type
+            )
             wrp = _tecutil.DataValueGetWritableRawPtrByRef(ref)
             if self._cache:
                 if not hasattr(self, '_wrp'):
@@ -164,8 +185,9 @@ class Array(c_void_p):
             else:
                 return wrp
         else:
-            _tecutil.handle.tecUtilDataValueGetReadableRawPtrByRef.restype = \
-                POINTER(self.c_type)
+            _tecutil.handle.tecUtilDataValueGetReadableRawPtrByRef.restype = POINTER(
+                self.c_type
+            )
             rrp = _tecutil.DataValueGetReadableRawPtrByRef(self)
             if self._cache:
                 if not hasattr(self, '_rrp'):
@@ -202,6 +224,12 @@ class Array(c_void_p):
         else:
             return _tecutil.DataValueGetCountByRef(self)
 
+    def _value_location(self):
+        with self.zone.dataset.frame.activated():
+            return _tecutil.DataValueGetLocation(
+                self.zone.index + 1, self.variable.index + 1
+            )
+
     @property
     def location(self):
         """`ValueLocation`: Data points location with respect to the elements.
@@ -214,12 +242,10 @@ class Array(c_void_p):
         """
         if self._cache:
             if not hasattr(self, '_location'):
-                self._location = _tecutil.DataValueGetLocation(
-                    self.zone.index + 1, self.variable.index + 1)
+                self._location = self._value_location()
             return self._location
         else:
-            return _tecutil.DataValueGetLocation(self.zone.index + 1,
-                                                 self.variable.index + 1)
+            return self._value_location()
 
     @property
     def shape(self):
@@ -318,7 +344,8 @@ class Array(c_void_p):
             FieldDataType.Double: ctypes.c_double,
             FieldDataType.Int32: ctypes.c_int32,
             FieldDataType.Int16: ctypes.c_int16,
-            FieldDataType.Byte: ctypes.c_int8}
+            FieldDataType.Byte: ctypes.c_int8,
+        }
         return _ctypes[self.data_type]
 
     @property
@@ -360,7 +387,7 @@ class Array(c_void_p):
             >>> x = dataset.zone('Zone').values('X').as_ctypes_array()
         """
         size = (len(self) - offset) if size is None else size
-        CArray = (self.c_type * size)
+        CArray = self.c_type * size
         if copy:
             arr = CArray()
             _tecutil.DataValueArrayGetByRef(self, offset + 1, size, arr)
@@ -368,8 +395,7 @@ class Array(c_void_p):
         else:
             ptr = self._raw_pointer(True)
             if offset:
-                vptr = ctypes.cast(ctypes.pointer(ptr),
-                                   ctypes.POINTER(ctypes.c_void_p))
+                vptr = ctypes.cast(ctypes.pointer(ptr), ctypes.POINTER(ctypes.c_void_p))
                 vptr.contents.value += ctypes.sizeof(ptr._type_) * offset
             ptr_addr = ctypes.addressof(ptr.contents)
             arr = CArray.from_address(ptr_addr)
@@ -402,6 +428,7 @@ class Array(c_void_p):
             >>> x = dataset.zone('Zone').values('X').as_numpy_array()
         """
         import numpy as np
+
         carr = self.as_ctypes_array(offset, size, copy)
         return np.ctypeslib.as_array(carr)
 
@@ -441,11 +468,13 @@ class Array(c_void_p):
         try:
             return self.as_numpy_array(offset, size, copy=True)
         except ImportError:
-            msg = textwrap.dedent('''\
+            msg = textwrap.dedent(
+                """\
                 Falling back to using basic Python for data operations.
                 If installed, PyTecplot will make use of Numpy where
                 appropriate for significant performance gains.
-            ''')
+            """
+            )
             log.warning(msg)
             return self.as_ctypes_array(offset, size, copy=True)
 
@@ -506,22 +535,23 @@ class Array(c_void_p):
 
                 if isinstance(val, Array):
                     if (
-                        offset == 0 and
-                        size in (None, len(self)) and
-                        val.zone.dataset == self.zone.dataset
+                        offset == 0
+                        and size in (None, len(self))
+                        and val.zone.dataset == self.zone.dataset
                     ):
                         # copy whole array
                         if val.zone == self.zone:
-                            eqn = 'V{0} = V{1}'.format(self.variable.index + 1,
-                                                       val.variable.index + 1)
+                            eqn = 'V{0} = V{1}'.format(
+                                self.variable.index + 1, val.variable.index + 1
+                            )
                             operate.execute_equation(eqn, self.zone)
                         else:
                             src_zone_idx = self.zone.index
                             tgt_zone_idx = val.zone.index
                             var_idx = val.variable.index
-                            if not _tecutil.DataValueCopy(src_zone_idx + 1,
-                                                          tgt_zone_idx + 1,
-                                                          var_idx + 1):
+                            if not _tecutil.DataValueCopy(
+                                src_zone_idx + 1, tgt_zone_idx + 1, var_idx + 1
+                            ):
                                 raise TecplotSystemError()
                         return
                     else:
@@ -535,17 +565,20 @@ class Array(c_void_p):
                     # coerce val to a ctypes array, using numpy if available
                     try:
                         import numpy as np
+
                         nparr = np.asarray(val, dtype=ctype)
                         ptarr = nparr.ctypes.data_as(POINTER(ctype))
                         ptaddr = addressof(ptarr.contents)
                         arr = (ctype * size).from_address(ptaddr)
                     except ImportError:
-                        msg = textwrap.dedent('''\
+                        msg = textwrap.dedent(
+                            """\
                             Falling back to using basic Python for data
                             operations. If installed, PyTecplot will make use
                             of Numpy where appropriate for significant
                             performance gains.
-                        ''')
+                        """
+                        )
                         log.warning(msg)
                         arr = (ctype * size)(*val)
 
@@ -606,7 +639,7 @@ class Array(c_void_p):
 
     @property
     def shared_zones(self):
-        """`list` of `Zones <data_access>`: All `Zones <data_access>` sharing this array.
+        """`list` of `Zones <data_access>`: All zones sharing this array.
 
         Example usage::
 
@@ -616,10 +649,14 @@ class Array(c_void_p):
             0
             1
         """
-        indices = _tecutil.DataValueGetShareZoneSet(self.zone.index + 1,
-                                                    self.variable.index + 1)
-        ret = [self.zone.dataset.zone(i) for i in indices]
-        indices.dealloc()
+        with self.zone.dataset.frame.activated():
+            indices = _tecutil.DataValueGetShareZoneSet(
+                self.zone.index + 1, self.variable.index + 1
+            )
+            try:
+                ret = [self.zone.dataset.zone(i) for i in indices]
+            finally:
+                indices.dealloc()
         return ret
 
     @property
@@ -638,5 +675,7 @@ class Array(c_void_p):
             z = ds.add_ordered_zone('Z1', (3,))
             assert not z.values(0).passive
         """
-        return _tecutil.DataValueIsPassive(self.zone.index + 1,
-                                           self.variable.index + 1)
+        with self.zone.dataset.frame.activated():
+            return _tecutil.DataValueIsPassive(
+                self.zone.index + 1, self.variable.index + 1
+            )
