@@ -1,13 +1,18 @@
+from __future__ import annotations
+
 import contextlib
 import ctypes
 import logging
 import numbers
+import typing
 
 from ..tecutil import _tecutil, sv
 from ..constant import *
 from ..exception import *
 from .. import annotation, constant, plot, session, tecutil
 
+if typing.TYPE_CHECKING:
+    from ..data import Dataset
 
 log = logging.getLogger(__name__)
 
@@ -60,6 +65,9 @@ class Frame(session.Style):
         print(page.name)
     """
 
+    dataset: Dataset = None
+    """The `Dataset <tecplot.data.Dataset>` belonging to this Frame."""
+
     def __init__(self, uid, page):
         self.page = page
         self.uid = uid
