@@ -3,6 +3,7 @@ from builtins import int, super
 import itertools as it
 
 from collections.abc import Iterable
+from warnings import warn
 
 from ..tecutil import _tecutil, sv
 from ..constant import *
@@ -1533,9 +1534,14 @@ class SliceGroup(SliceGroupCollection):
         result = super().extract(mode, assign_strand_ids,
                                  resulting_1d_zone_type, transient_mode)
         if (
-            mode == ExtractMode.SingleZone and
-            transient_mode == TransientOperationMode.SingleSolutionTime
+            mode == ExtractMode.SingleZone
+            and transient_mode == TransientOperationMode.SingleSolutionTime
         ):
-            return list(result)[0]
-        else:
-            return result
+            warn("extract() will always return a generator" +
+                 " in future versions of PyTecplot")
+            if (
+                self.show_primary_slice == True
+                and self.show_start_and_end_slices == False
+            ):
+                return list(result)[0]
+        return result
