@@ -5,8 +5,10 @@ import logging
 import platform
 import textwrap
 
-from ..tecutil import _tecutil_connector
+from ..tecutil import _tecutil, _tecutil_connector, lock
+from ..constant import *
 from ..exception import *
+from .. import macro
 from .state_changed import _emit_state_changes
 
 
@@ -155,12 +157,14 @@ def start_roaming(days):
         Your PyTecplot roaming license has been checked in.
     """
     if _tecutil_connector.connected:
-        msg = textwrap.dedent('''\
+        msg = textwrap.dedent(
+            """\
             Roaming PyTecplot is not available when connected.
             To roam PyTecplot, first disconnect with
             tecplot.session.disconnect(). Roaming with Tecplot 360
             is available under Help -> License Roaming.
-        ''')
+        """
+        )
         raise TecplotLogicError(msg)
     _tecutil_connector.start_roaming(days)
 
@@ -179,12 +183,14 @@ def stop_roaming(force=False):
         Your PyTecplot roaming license has been checked in.
     """
     if _tecutil_connector.connected:
-        msg = textwrap.dedent('''\
+        msg = textwrap.dedent(
+            """\
             Roaming PyTecplot is not available when connected.
             To roam PyTecplot, first disconnect with
             tecplot.session.disconnect(). Roaming with Tecplot 360
             is available under Help -> License Roaming.
-        ''')
+        """
+        )
         raise TecplotLogicError(msg)
     _tecutil_connector.stop_roaming(force)
 
@@ -421,5 +427,55 @@ def clear_suspend():
     _tecutil_connector.client.clear_suspend_interface()
 
 
+def redraw():
+    """Force a refresh of all plots on the screen (connected mode only).
+
+    Forcibly updates all plots and renders everything to the screen. This is useful when
+    connected to a live instance of Tecplot 360 where updates faster than one second
+    (the default) is desired. This command is ignored in batch mode.
+
+    Eample usage::
+
+        for i in range(10):
+            zone.values('s')[:] = new_data
+            tp.session.redraw() # force redraw on screen before continuing script
+
+    .. versionadded:: 1.7
+        `redraw()` added in PyTecplot 1.7.0.
+
+    .. versionadded:: 2025.1
+        Forcing a redraw is supported in Tecplot 360 2025 R1 and later. For earlier
+        versions of Tecplot 360, the redraw is deferred but guaranteed to happen
+        within one second after the call.
+    """
+    tuclient = _tecutil_connector.client
+    if tuclient:
+        try:
+            """
+            Developer's note:
+                The TecUtilServer goes to great length to shutdown the user interface to
+                keep processing PyTecplot scripts in connected mode fast. Drawing to the
+                screen in Tecplot 360 requires that the Tecplot engine take control
+                which means the server must release it's control. We do this by
+                temporarily setting the server to "single command" mode, then asking if
+                automatic redraw is active. If it is, then the interface will
+                immediately draw. If not, then we just toggle it on then off which will
+                cause the whole workarea to redraw, updating anything that was changed
+                since the last draw.
+            """
+            tuclient.processing_mode = TecUtilServerProcessingMode.Single
+            if not _tecutil.AutoRedrawIsActive():
+                try:
+                    macro.execute_command('''
+                        $!Interface AutoRedraw { IsActive=True }
+                    ''')
+                finally:
+                    macro.execute_command('''
+                        $!Interface AutoRedraw { IsActive=False }
+                    ''')
+        finally:
+            tuclient.processing_mode = TecUtilServerProcessingMode.Unspecified
+
+
 # Ensure the Tecplot engine is cleaned up on exit if started.
 atexit.register(stop)
