@@ -713,6 +713,10 @@ class TestDataset(unittest.TestCase):
         self.assertEqual(zcopy6[1].values(0).shared_zones, [])
         self.assertEqual(zcopy6[1].values(1).shared_zones, [])
 
+        zcopy7 = ds.copy_zones(z,share_variables=ds.variables())
+        self.assertEqual(zcopy7[0].values(0).shared_zones, [z,zcopy2[0],zcopy5[0],zcopy7[0]])
+        self.assertEqual(zcopy7[0].values(1).shared_zones, [z,zcopy2[0],zcopy4[0],zcopy7[0]])
+
     def test_variable_sharing(self):
         tp.new_layout()
         ds = tp.active_page().add_frame().create_dataset('D', ['x','y'])
