@@ -14,7 +14,7 @@ from tecplot.tecutil import Index
 from test import patch_tecutil
 from tecplot.plot import ContourGroup
 
-from test import (assert_style, sample_data, skip_if_sdk_version_before,
+from test import (assert_style, sample_data, skip_if_sdk_version_before, skip_if_connected,
                   mocked_sdk_version)
 
 
@@ -489,6 +489,7 @@ class TestSliceGroup(unittest.TestCase):
             with self.assertRaises((TecplotSystemError, TecplotLogicError)):
                 self.slice.extract()
 
+    @skip_if_connected
     def test_extract_none(self):
         self.slice.show_start_and_end_slices=False
         self.slice.show_primary_slice=False
@@ -507,6 +508,7 @@ class TestSliceGroup(unittest.TestCase):
             with self.assertRaises((TecplotSystemError, TecplotLogicError)):
                 self.slice.extract()
 
+    @skip_if_connected
     def test_extract_show_start_end(self):
         self.slice.show_start_and_end_slices=True
         self.slice.show_primary_slice=False
@@ -525,6 +527,8 @@ class TestSliceGroup(unittest.TestCase):
             with self.assertRaises((TecplotSystemError, TecplotLogicError)):
                 self.slice.extract()
 
+    
+    @skip_if_connected
     def test_extract_show_primary(self):
         # The only instance in which a single zone is returned.
         self.slice.show_start_and_end_slices=False
@@ -543,6 +547,7 @@ class TestSliceGroup(unittest.TestCase):
             with self.assertRaises((TecplotSystemError, TecplotLogicError)):
                 self.slice.extract()
 
+    @skip_if_connected
     def test_extract_show_primary_and_start_end(self):
         self.slice.show_start_and_end_slices=True
         self.slice.show_primary_slice=True
@@ -574,6 +579,7 @@ class TestSliceGroup(unittest.TestCase):
         z = list(z)
         self.assertGreater(len(z), 1)
     
+    @skip_if_connected
     def test_extract_single_transient(self):
         self.dataset.zone(0).strand = 1
         self.dataset.zone(0).solution_time = 1.0
