@@ -1,9 +1,9 @@
-from __future__ import unicode_literals, print_function
-
 import ctypes
 import fnmatch
 import inspect
+import itertools as it
 import logging
+import math
 import numpy
 import numpy as np
 import os
@@ -26,10 +26,12 @@ from tecplot.constant import *
 from tecplot.exception import *
 from tecplot.data.operate import *
 
+from test import skip_on, skip_if_sdk_version_before
+
 doc_ptrn = re.compile(r'((\s*)    import tecplot.*?)(?:^\2\S)', re.M | re.S)
 import_from_ptrn = re.compile(r'^\s*from.*?import\s*([(].*?[)]|.*?$)\n', re.M | re.S)
 import_ptrn = re.compile(r'\s*import.*')
-export_ptrn = re.compile(r'\s*.*?export.*', re.M)
+export_ptrn = re.compile(r'\s*.*?export.*\)', re.M)
 
 def find_examples(doc):
     """
@@ -45,7 +47,7 @@ def find_examples(doc):
         ex = dedent(m.group(1))
         ex = import_from_ptrn.sub('', ex)
         ex = import_ptrn.sub('', ex)
-        ex = export_ptrn.sub('', ex)
+        ex = export_ptrn.sub('', ex, re.M)
         yield ex.strip()
 
 def submodules(module, ignore):
@@ -82,13 +84,16 @@ def methods(class_, ignore=['__init__', '__weakref__'], inherited=False):
     """
     yields all methods directly defined in a given class.
     """
+    #print(class_.__name__)
     def ismember(obj):
-        return inspect.ismethod(obj) or inspect.isdatadescriptor(obj) and \
-               not inspect.isbuiltin(obj)
+        return inspect.ismethod(obj) or inspect.isfunction(obj) or \
+               inspect.ismethoddescriptor(obj) or \
+               inspect.isdatadescriptor(obj) and not inspect.isbuiltin(obj)
     for method_name,method in inspect.getmembers(class_,ismember):
-        if method_name not in ignore:
-            if inherited or method_name in class_.__dict__:
-                yield method_name,method
+        if ismember(method):
+            if method_name not in ignore:
+                if inherited or method_name in class_.__dict__:
+                    yield method_name,method
 
 def object_definitions(module, ignore_modules):
     """
@@ -105,11 +110,11 @@ def object_definitions(module, ignore_modules):
                 method_fullname = '.'.join([member_fullname,method_name])
                 yield method_fullname, method
 
+
 class TestDocExamples(unittest.TestCase):
     """
     all doc-example tests will be patched into this class
     """
-    pass
 
 ignore_modules = ['*tecutil.constant*', '*exception*']
 
@@ -122,14 +127,18 @@ for objname, obj in object_definitions(tp, ignore_modules):
     doc = obj.__doc__
     if doc:
         for count,ex in enumerate(find_examples(doc)):
+            @skip_on(TecplotOutOfDateEngineError)
             def _fn(self, ex=ex):
                 tp.new_layout()
-                exec(ex)
+                with tp.session.suspend():
+                    exec(ex)
             attrname = 'test_'+objname.replace('.','_')+'_ex'+str(count)
-            #if objname.replace('.','_') == 'tecplot_plot_fieldmap_FieldmapContour':
-            #    print(ex)
+            #if 'ordered_zone' in objname:
+            #    print(objname)
+            #    print(attrname)
             setattr(TestDocExamples, attrname, _fn)
 
+
 if __name__ == '__main__':
-    from . import main
-    main()
+    import test
+    test.main()
